/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM flockIMediaEmbedWebService.idl
 */

#ifndef __gen_flockIMediaEmbedWebService_h__
#define __gen_flockIMediaEmbedWebService_h__


#ifndef __gen_flockIMediaWebService_h__
#include "flockIMediaWebService.h"
#endif

#ifndef __gen_flockIListener_h__
#include "flockIListener.h"
#endif

#ifndef __gen_nsIDOMHTMLElement_h__
#include "nsIDOMHTMLElement.h"
#endif

#ifndef __gen_nsIWritablePropertyBag2_h__
#include "nsIWritablePropertyBag2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    flockIMediaEmbedWebService */
#define FLOCKIMEDIAEMBEDWEBSERVICE_IID_STR "8ab8eb98-ce68-4a8b-b4e0-b6d4ef9b1dc2"

#define FLOCKIMEDIAEMBEDWEBSERVICE_IID \
  {0x8ab8eb98, 0xce68, 0x4a8b, \
    { 0xb4, 0xe0, 0xb6, 0xd4, 0xef, 0x9b, 0x1d, 0xc2 }}

/**
 * Represents a web service that supports browsing of streams or collections of
 * rich media (eg. photos, video).
 *
 * @see flockIMediaWebService
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockIMediaEmbedWebService : public flockIMediaWebService {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIMEDIAEMBEDWEBSERVICE_IID)

  /**
   * Determine if the passed in URL represents a media stream for this
   * particular flockIMediaService.
   *
   * @param aUrl The URL to evaluate.
   * @returns true if the passed in URL represents a media stream for this
   *          particular flockIMediaService.
   */
  /* boolean checkIsStreamUrl (in AString aUrl); */
  NS_SCRIPTABLE NS_IMETHOD CheckIsStreamUrl(const nsAString & aUrl, PRBool *_retval) = 0;

  /**
   * Generate a media query from the passed in URL.
   * @param aUrl The URL to derive the media query from.
   * @param aListener The flockIListener to send the results.
   */
  /* void getMediaQueryFromURL (in AString aUrl, in flockIListener aFlockListener); */
  NS_SCRIPTABLE NS_IMETHOD GetMediaQueryFromURL(const nsAString & aUrl, flockIListener *aFlockListener) = 0;

  /**
   * Retrieve the content URL and title.
   *
   * @param aSrc Source element.
   * @param aProp Container for retrieved property results.
   * @returns true if a service handled the request.
   */
  /* boolean getSharingContent (in nsIDOMHTMLElement aSrc, in nsIWritablePropertyBag2 aProp); */
  NS_SCRIPTABLE NS_IMETHOD GetSharingContent(nsIDOMHTMLElement *aSrc, nsIWritablePropertyBag2 *aProp, PRBool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIMediaEmbedWebService, FLOCKIMEDIAEMBEDWEBSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIMEDIAEMBEDWEBSERVICE \
  NS_SCRIPTABLE NS_IMETHOD CheckIsStreamUrl(const nsAString & aUrl, PRBool *_retval); \
  NS_SCRIPTABLE NS_IMETHOD GetMediaQueryFromURL(const nsAString & aUrl, flockIListener *aFlockListener); \
  NS_SCRIPTABLE NS_IMETHOD GetSharingContent(nsIDOMHTMLElement *aSrc, nsIWritablePropertyBag2 *aProp, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIMEDIAEMBEDWEBSERVICE(_to) \
  NS_SCRIPTABLE NS_IMETHOD CheckIsStreamUrl(const nsAString & aUrl, PRBool *_retval) { return _to CheckIsStreamUrl(aUrl, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMediaQueryFromURL(const nsAString & aUrl, flockIListener *aFlockListener) { return _to GetMediaQueryFromURL(aUrl, aFlockListener); } \
  NS_SCRIPTABLE NS_IMETHOD GetSharingContent(nsIDOMHTMLElement *aSrc, nsIWritablePropertyBag2 *aProp, PRBool *_retval) { return _to GetSharingContent(aSrc, aProp, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIMEDIAEMBEDWEBSERVICE(_to) \
  NS_SCRIPTABLE NS_IMETHOD CheckIsStreamUrl(const nsAString & aUrl, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckIsStreamUrl(aUrl, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMediaQueryFromURL(const nsAString & aUrl, flockIListener *aFlockListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMediaQueryFromURL(aUrl, aFlockListener); } \
  NS_SCRIPTABLE NS_IMETHOD GetSharingContent(nsIDOMHTMLElement *aSrc, nsIWritablePropertyBag2 *aProp, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSharingContent(aSrc, aProp, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIMediaEmbedWebService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIMEDIAEMBEDWEBSERVICE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIMediaEmbedWebService)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* boolean checkIsStreamUrl (in AString aUrl); */
NS_IMETHODIMP _MYCLASS_::CheckIsStreamUrl(const nsAString & aUrl, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getMediaQueryFromURL (in AString aUrl, in flockIListener aFlockListener); */
NS_IMETHODIMP _MYCLASS_::GetMediaQueryFromURL(const nsAString & aUrl, flockIListener *aFlockListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getSharingContent (in nsIDOMHTMLElement aSrc, in nsIWritablePropertyBag2 aProp); */
NS_IMETHODIMP _MYCLASS_::GetSharingContent(nsIDOMHTMLElement *aSrc, nsIWritablePropertyBag2 *aProp, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_flockIMediaEmbedWebService_h__ */
